summaryrefslogtreecommitdiff
path: root/src/com/android/customization/model/themedicon/ThemedIconSectionController.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/android/customization/model/themedicon/ThemedIconSectionController.java')
-rw-r--r--src/com/android/customization/model/themedicon/ThemedIconSectionController.java7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/com/android/customization/model/themedicon/ThemedIconSectionController.java b/src/com/android/customization/model/themedicon/ThemedIconSectionController.java
index 32fbfa87..9ec5c2cb 100644
--- a/src/com/android/customization/model/themedicon/ThemedIconSectionController.java
+++ b/src/com/android/customization/model/themedicon/ThemedIconSectionController.java
@@ -22,14 +22,15 @@ import androidx.annotation.Nullable;
import com.android.customization.picker.themedicon.ThemedIconSectionView;
import com.android.wallpaper.R;
-import com.android.wallpaper.model.HubSectionController;
+import com.android.wallpaper.model.CustomizationSectionController;
import com.android.wallpaper.model.WorkspaceViewModel;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
-/** The {@link HubSectionController} for themed icon section. */
-public class ThemedIconSectionController implements HubSectionController<ThemedIconSectionView> {
+/** The {@link CustomizationSectionController} for themed icon section. */
+public class ThemedIconSectionController implements
+ CustomizationSectionController<ThemedIconSectionView> {
private final ThemedIconSwitchProvider mThemedIconOptionsProvider;
private final WorkspaceViewModel mWorkspaceViewModel;